.. aplex documentation master file, created by
   sphinx-quickstart on Thu Feb  7 17:40:38 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Aplex!
=====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

User's Guide
------------

.. toctree::
   :maxdepth: 2

   installation
   quickstart

API Reference
-------------

.. toctree::
   :maxdepth: 2

   api

Changelog
---------

.. toctree::
   :maxdepth: 2

   changelog

The Contributor Guide
---------------------

.. toctree::
   :maxdepth: 2

   contributing

License
-------

.. toctree::
   :maxdepth: 2

   license
